@@ -1,9 +1,9 @@
-# $Id: Negotiate.pm,v 1.7 1999/03/20 07:37:35 gisle Exp $
+# $Id: Negotiate.pm,v 1.13 2003/10/23 19:11:32 uid39246 Exp $
 #
 
 package HTTP::Negotiate;
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 sub Version { $VERSION; }
 
 require 5.002;
@@ -45,34 +45,46 @@ sub choose ($;$)
 
     $request->scan(sub {
 	my($key, $val) = @_;
-	return unless $key =~ s/^Accept-?//;
-	my $type = lc $key;
-	$type = "type" unless length $key;
+
+	my $type;
+	if ($key =~ s/^Accept-//) {
+	    $type = lc($key);
+	}
+	elsif ($key eq "Accept") {
+	    $type = "type";
+	}
+	else {
+	    return;
+	}
+
 	$val =~ s/\s+//g;
-	my $name;
-	for $name (split(/,/, $val)) {
+	my $default_q = 1;
+	for my $name (split(/,/, $val)) {
 	    my(%param, $param);
 	    if ($name =~ s/;(.*)//) {
 		for $param (split(/;/, $1)) {
 		    my ($pk, $pv) = split(/=/, $param, 2);
-		    $param{$pk} = $pv;
+		    $param{lc $pk} = $pv;
 		}
 	    }
 	    $name = lc $name;
 	    if (defined $param{'q'}) {
 		$param{'q'} = 1 if $param{'q'} > 1;
 		$param{'q'} = 0 if $param{'q'} < 0;
-	    } else {
-		$param{'q'} = 1;
 	    }
+	    else {
+		$param{'q'} = $default_q;
 
-	    $param{'q'} = 1 unless defined $param{'q'};
+		# This makes sure that the first ones are slightly better off
+		# and therefore more likely to be chosen.
+		$default_q -= 0.0001;
+	    }
 	    $accept{$type}{$name} = \%param;
 	}
     });
 
     # Check if any of the variants specify a language.  We do this
-    # because it influence how we treat those without (they default to
+    # because it influences how we treat those without (they default to
     # 0.5 instead of 1).
     my $any_lang = 0;
     for $var (@$variants) {
@@ -98,13 +110,15 @@ sub choose ($;$)
     my @Q = ();  # This is where we collect the results of the
 		 # quality calcualtions
 
-    # Calculate quality for all the variant's that are available.
+    # Calculate quality for all the variants that are available.
     for (@$variants) {
 	my($id, $qs, $ct, $enc, $cs, $lang, $bs) = @$_;
 	$qs = 1 unless defined $qs;
+        $ct = '' unless defined $ct;
 	$bs = 0 unless defined $bs;
+	$lang = lc($lang) if $lang; # lg tags are always case-insensitive
 	if ($DEBUG) {
-	    print "\nEvaluating $id ($ct)\n";
+	    print "\nEvaluating $id (ct='$ct')\n";
 	    printf "  qs   = %.3f\n", $qs;
 	    print  "  enc  = $enc\n"  if $enc && !ref($enc);
 	    print  "  enc  = @$enc\n" if $enc && ref($enc);
@@ -130,7 +144,8 @@ sub choose ($;$)
 		    print "no\n" if $DEBUG;
 		    $qe = 0;
 		    last;
-		} else {
+		}
+		else {
 		    print "yes\n" if $DEBUG;
 		}
 	    }
@@ -164,18 +179,29 @@ sub choose ($;$)
 		$q = $this_q unless defined $q;
 		$q = $this_q if $this_q > $q;
 	    }
-	    unless (defined $q) {
+	    if(defined $q) {
+	        $DEBUG and print " -- Exact language match at q=$q\n";
+	    }
+	    else {
 		# If there was no exact match and at least one of
 		# the Accept-Language field values is a complete
 		# subtag prefix of the content language tag(s), then
 		# the "q" parameter value of the largest matching
 		# prefix is used.
+		$DEBUG and print " -- No exact language match\n";
 		my $selected = undef;
 		for $al (keys %{ $accept{'language'} }) {
-		    if (substr($lang, 0, length($al)) eq $al) {
+		    if (substr($lang, 0, 1 + length($al)) eq "$al-") {
+		        # $lang starting with $al isn't enough, or else
+		        #  Accept-Language: hu (Hungarian) would seem
+		        #  to accept a document in hup (Hupa)
+		        $DEBUG and print " -- $lang ISA $al\n";
 			$selected = $al unless defined $selected;
 			$selected = $al if length($al) > length($selected);
 		    }
+		    else {
+		        $DEBUG and print " -- $lang  isn't a $al\n";
+		    }
 		}
 		$q = $accept{'language'}{$selected}{'q'} if $selected;
 
@@ -186,7 +212,8 @@ sub choose ($;$)
 		$q = 0.001 unless defined $q;
 	    }
 	    $ql = $q;
-	} else {
+	}
+	else {
 	    $ql = 0.5 if $any_lang && exists $accept{'language'};
 	}
 
@@ -251,14 +278,15 @@ sub choose ($;$)
 	my $Q;
 	if (!defined($mbx) || $mbx >= $bs) {
 	    $Q = $qs * $qe * $qc * $ql * $q;
-	} else {
+	}
+	else {
 	    $Q = 0;
 	    print "Variant's size is too large ==> Q=0\n" if $DEBUG;
 	}
 
 	if ($DEBUG) {
 	    $mbx = "undef" unless defined $mbx;
-	    printf "Q=%.3f", $Q;
+	    printf "Q=%.4f", $Q;
 	    print "  (q=$q, mbx=$mbx, qe=$qe, qc=$qc, ql=$ql, qs=$qs)\n";
 	}
 
@@ -323,12 +351,12 @@ parameter is missing, then the accept specification is initialized
 from the CGI environment variables HTTP_ACCEPT, HTTP_ACCEPT_CHARSET,
 HTTP_ACCEPT_ENCODING and HTTP_ACCEPT_LANGUAGE.
 
-In an array context, choose() returns a list of variant
-identifier/calculated quality pairs.  The values are sorted by
+In an array context, choose() returns a list of [variant
+identifier, calculated quality, size] tuples.  The values are sorted by
 quality, highest quality first.  If the calculated quality is the same
 for two variants, then they are sorted by size (smallest first). I<E.g.>:
 
-  (['var1' => 1], ['var2', 0.3], ['var3' => 0]);
+  (['var1', 1, 2000], ['var2', 0.3, 512], ['var3', 0.3, 1024]);
 
 Note that also zero quality variants are included in the return list
 even if these should never be served to the client.
@@ -411,7 +439,7 @@ language is in this context a natural language spoken, written, or
 otherwise conveyed by human beings for communication of information to
 other human beings.  Computer languages are explicitly excluded.
 
-The language tags are defined by RFC-1766.  Examples
+The language tags are defined by RFC 3066.  Examples
 are:
 
   no               Norwegian
@@ -492,13 +520,13 @@ would mean: "I prefer Norwegian, but will accept British English (with
 
 =head1 COPYRIGHT
 
-Copyright 1996, Gisle Aas.
+Copyright 1996,2001 Gisle Aas.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Gisle Aas <aas@sn.no>
+Gisle Aas <gisle@aas.no>
 
 =cut
