@@ -1,8 +1,100 @@
-#
-# $Id: Request.pm,v 1.31 2003/10/16 10:54:16 gisle Exp $
-
 package HTTP::Request;
 
+# $Id: Request.pm,v 1.33 2003/10/23 19:11:32 uid39246 Exp $
+
+require HTTP::Message;
+@ISA = qw(HTTP::Message);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.33 $ =~ /(\d+)\.(\d+)/);
+
+use strict;
+
+
+
+sub new
+{
+    my($class, $method, $uri, $header, $content) = @_;
+    my $self = $class->SUPER::new($header, $content);
+    $self->method($method);
+    $self->uri($uri);
+    $self;
+}
+
+
+sub clone
+{
+    my $self = shift;
+    my $clone = bless $self->SUPER::clone, ref($self);
+    $clone->method($self->method);
+    $clone->uri($self->uri);
+    $clone;
+}
+
+
+sub method
+{
+    shift->_elem('_method', @_);
+}
+
+
+sub uri
+{
+    my $self = shift;
+    my $old = $self->{'_uri'};
+    if (@_) {
+	my $uri = shift;
+	if (!defined $uri) {
+	    # that's ok
+	}
+	elsif (ref $uri) {
+	    Carp::croak("A URI can't be a " . ref($uri) . " reference")
+		if ref($uri) eq 'HASH' or ref($uri) eq 'ARRAY';
+	    Carp::croak("Can't use a " . ref($uri) . " object as a URI")
+		unless $uri->can('scheme');
+	    $uri = $uri->clone;
+	    unless ($HTTP::URI_CLASS eq "URI") {
+		# Argh!! Hate this... old LWP legacy!
+		eval { local $SIG{__DIE__}; $uri = $uri->abs; };
+		die $@ if $@ && $@ !~ /Missing base argument/;
+	    }
+	}
+	else {
+	    $uri = $HTTP::URI_CLASS->new($uri);
+	}
+	$self->{'_uri'} = $uri;
+    }
+    $old;
+}
+
+*url = \&uri;  # legacy
+
+
+sub as_string
+{
+    my $self = shift;
+    my @result;
+    #push(@result, "---- $self -----");
+    my $req_line = $self->method || "[NO METHOD]";
+    my $uri = $self->uri;
+    $uri = (defined $uri) ? $uri->as_string : "[NO URI]";
+    $req_line .= " $uri";
+    my $proto = $self->protocol;
+    $req_line .= " $proto" if $proto;
+
+    push(@result, $req_line);
+    push(@result, $self->headers_as_string);
+    my $content = $self->content;
+    if (defined $content) {
+	push(@result, $content);
+    }
+    #push(@result, ("-" x 40));
+    join("\n", @result, "");
+}
+
+
+1;
+
+__END__
+
 =head1 NAME
 
 HTTP::Request - Class encapsulating HTTP Requests
@@ -34,14 +126,6 @@ The following additional methods are available:
 
 =over 4
 
-=cut
-
-require HTTP::Message;
-@ISA = qw(HTTP::Message);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.31 $ =~ /(\d+)\.(\d+)/);
-
-use strict;
-
 =item $r = HTTP::Request->new($method, $uri)
 
 =item $r = HTTP::Request->new($method, $uri, $header)
@@ -54,28 +138,6 @@ either a string, or a reference to a C<URI> object.  The optional $header
 argument should be a reference to an C<HTTP::Headers> object.
 The optional $content argument should be a string.
 
-=cut
-
-sub new
-{
-    my($class, $method, $uri, $header, $content) = @_;
-    my $self = $class->SUPER::new($header, $content);
-    $self->method($method);
-    $self->uri($uri);
-    $self;
-}
-
-
-sub clone
-{
-    my $self = shift;
-    my $clone = bless $self->SUPER::clone, ref($self);
-    $clone->method($self->method);
-    $clone->uri($self->uri);
-    $clone;
-}
-
-
 =item $r->method
 
 =item $r->method( $val )
@@ -98,70 +160,11 @@ The uri() method accept both a reference to a URI object and a
 string as its argument.  If a string is given, then it should be
 parseable as an absolute URI.
 
-=cut
-
-sub method  { shift->_elem('_method', @_); }
-
-sub uri
-{
-    my $self = shift;
-    my $old = $self->{'_uri'};
-    if (@_) {
-	my $uri = shift;
-	if (!defined $uri) {
-	    # that's ok
-	} elsif (ref $uri) {
-	    Carp::croak("A URI can't be a " . ref($uri) . " reference")
-		if ref($uri) eq 'HASH' or ref($uri) eq 'ARRAY';
-	    Carp::croak("Can't use a " . ref($uri) . " object as a URI")
-		unless $uri->can('scheme');
-	    $uri = $uri->clone;
-	    unless ($HTTP::URI_CLASS eq "URI") {
-		# Argh!! Hate this... old LWP legacy!
-		eval { local $SIG{__DIE__}; $uri = $uri->abs; };
-		die $@ if $@ && $@ !~ /Missing base argument/;
-	    }
-	} else {
-	    $uri = $HTTP::URI_CLASS->new($uri);
-	}
-	$self->{'_uri'} = $uri;
-    }
-    $old;
-}
-
-*url = \&uri;  # this is the same for now
-
 =item $r->as_string
 
 Method returning a textual representation of the request.
 Mainly useful for debugging purposes. It takes no arguments.
 
-=cut
-
-sub as_string
-{
-    my $self = shift;
-    my @result;
-    #push(@result, "---- $self -----");
-    my $req_line = $self->method || "[NO METHOD]";
-    my $uri = $self->uri;
-    $uri = (defined $uri) ? $uri->as_string : "[NO URI]";
-    $req_line .= " $uri";
-    my $proto = $self->protocol;
-    $req_line .= " $proto" if $proto;
-
-    push(@result, $req_line);
-    push(@result, $self->headers_as_string);
-    my $content = $self->content;
-    if (defined $content) {
-	push(@result, $content);
-    }
-    #push(@result, ("-" x 40));
-    join("\n", @result, "");
-}
-
-1;
-
 =back
 
 =head1 SEE ALSO
@@ -175,4 +178,3 @@ Copyright 1995-2001 Gisle Aas.
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-=cut
