@@ -1,8 +1,211 @@
-#
-# $Id: Response.pm,v 1.38 2003/10/16 10:54:16 gisle Exp $
-
 package HTTP::Response;
 
+# $Id: Response.pm,v 1.40 2003/10/23 19:11:32 uid39246 Exp $
+
+require HTTP::Message;
+@ISA = qw(HTTP::Message);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.40 $ =~ /(\d+)\.(\d+)/);
+
+use strict;
+use HTTP::Status ();
+
+
+
+sub new
+{
+    my($class, $rc, $msg, $header, $content) = @_;
+    my $self = $class->SUPER::new($header, $content);
+    $self->code($rc);
+    $self->message($msg);
+    $self;
+}
+
+
+sub clone
+{
+    my $self = shift;
+    my $clone = bless $self->SUPER::clone, ref($self);
+    $clone->code($self->code);
+    $clone->message($self->message);
+    $clone->request($self->request->clone) if $self->request;
+    # we don't clone previous
+    $clone;
+}
+
+
+sub code      { shift->_elem('_rc',      @_); }
+sub message   { shift->_elem('_msg',     @_); }
+sub previous  { shift->_elem('_previous',@_); }
+sub request   { shift->_elem('_request', @_); }
+
+
+sub status_line
+{
+    my $self = shift;
+    my $code = $self->{'_rc'}  || "000";
+    my $mess = $self->{'_msg'} || HTTP::Status::status_message($code) || "?";
+    return "$code $mess";
+}
+
+
+sub base
+{
+    my $self = shift;
+    my $base = $self->header('Content-Base')     ||  # used to be HTTP/1.1
+               $self->header('Content-Location') ||  # HTTP/1.1
+               $self->header('Base');                # HTTP/1.0
+    return $HTTP::URI_CLASS->new_abs($base, $self->request->uri);
+    # So yes, if $base is undef, the return value is effectively
+    # just a copy of $self->request->uri.
+}
+
+
+sub as_string
+{
+    require HTTP::Status;
+    my $self = shift;
+    my @result;
+    #push(@result, "---- $self ----");
+    my $code = $self->code;
+    my $status_message = HTTP::Status::status_message($code) || "Unknown code";
+    my $message = $self->message || "";
+
+    my $status_line = "$code";
+    my $proto = $self->protocol;
+    $status_line = "$proto $status_line" if $proto;
+    $status_line .= " ($status_message)" if $status_message ne $message;
+    $status_line .= " $message";
+    push(@result, $status_line);
+    push(@result, $self->headers_as_string);
+    my $content = $self->content;
+    if (defined $content) {
+	push(@result, $content);
+    }
+    #push(@result, ("-" x 40));
+    join("\n", @result, "");
+}
+
+
+sub is_info     { HTTP::Status::is_info     (shift->{'_rc'}); }
+sub is_success  { HTTP::Status::is_success  (shift->{'_rc'}); }
+sub is_redirect { HTTP::Status::is_redirect (shift->{'_rc'}); }
+sub is_error    { HTTP::Status::is_error    (shift->{'_rc'}); }
+
+
+sub error_as_HTML
+{
+    my $self = shift;
+    my $title = 'An Error Occurred';
+    my $body  = $self->status_line;
+    return <<EOM;
+<HTML>
+<HEAD><TITLE>$title</TITLE></HEAD>
+<BODY>
+<H1>$title</H1>
+$body
+</BODY>
+</HTML>
+EOM
+}
+
+
+sub current_age
+{
+    my $self = shift;
+    # Implementation of <draft-ietf-http-v11-spec-07> section 13.2.3
+    # (age calculations)
+    my $response_time = $self->client_date;
+    my $date = $self->date;
+
+    my $age = 0;
+    if ($response_time && $date) {
+	$age = $response_time - $date;  # apparent_age
+	$age = 0 if $age < 0;
+    }
+
+    my $age_v = $self->header('Age');
+    if ($age_v && $age_v > $age) {
+	$age = $age_v;   # corrected_received_age
+    }
+
+    my $request = $self->request;
+    if ($request) {
+	my $request_time = $request->date;
+	if ($request_time) {
+	    # Add response_delay to age to get 'corrected_initial_age'
+	    $age += $response_time - $request_time;
+	}
+    }
+    if ($response_time) {
+	$age += time - $response_time;
+    }
+    return $age;
+}
+
+
+sub freshness_lifetime
+{
+    my $self = shift;
+
+    # First look for the Cache-Control: max-age=n header
+    my @cc = $self->header('Cache-Control');
+    if (@cc) {
+	my $cc;
+	for $cc (@cc) {
+	    my $cc_dir;
+	    for $cc_dir (split(/\s*,\s*/, $cc)) {
+		if ($cc_dir =~ /max-age\s*=\s*(\d+)/i) {
+		    return $1;
+		}
+	    }
+	}
+    }
+
+    # Next possibility is to look at the "Expires" header
+    my $date = $self->date || $self->client_date || time;      
+    my $expires = $self->expires;
+    unless ($expires) {
+	# Must apply heuristic expiration
+	my $last_modified = $self->last_modified;
+	if ($last_modified) {
+	    my $h_exp = ($date - $last_modified) * 0.10;  # 10% since last-mod
+	    if ($h_exp < 60) {
+		return 60;  # minimum
+	    }
+	    elsif ($h_exp > 24 * 3600) {
+		# Should give a warning if more than 24 hours according to
+		# <draft-ietf-http-v11-spec-07> section 13.2.4, but I don't
+		# know how to do it from this function interface, so I just
+		# make this the maximum value.
+		return 24 * 3600;
+	    }
+	    return $h_exp;
+	}
+	else {
+	    return 3600;  # 1 hour is fallback when all else fails
+	}
+    }
+    return $expires - $date;
+}
+
+
+sub is_fresh
+{
+    my $self = shift;
+    $self->freshness_lifetime > $self->current_age;
+}
+
+
+sub fresh_until
+{
+    my $self = shift;
+    return $self->freshness_lifetime - $self->current_age + time;
+}
+
+1;
+
+
+__END__
 
 =head1 NAME
 
@@ -26,7 +229,8 @@ C<request()> method of an C<LWP::UserAgent> object:
  $response = $ua->request($request)
  if ($response->is_success) {
      print $response->content;
- } else {
+ }
+ else {
      print $response->error_as_HTML;
  }
 
@@ -40,17 +244,6 @@ The following additional methods are available:
 
 =over 4
 
-=cut
-
-
-require HTTP::Message;
-@ISA = qw(HTTP::Message);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.38 $ =~ /(\d+)\.(\d+)/);
-
-use HTTP::Status ();
-use strict;
-
-
 =item $r = HTTP::Response->new( $rc )
 
 =item $r = HTTP::Response->new( $rc, $msg )
@@ -64,29 +257,6 @@ response code C<$rc> and optional message C<$msg>.  The message is a
 short human readable single line string that explains the response
 code.
 
-=cut
-
-sub new
-{
-    my($class, $rc, $msg, $header, $content) = @_;
-    my $self = $class->SUPER::new($header, $content);
-    $self->code($rc);
-    $self->message($msg);
-    $self;
-}
-
-
-sub clone
-{
-    my $self = shift;
-    my $clone = bless $self->SUPER::clone, ref($self);
-    $clone->code($self->code);
-    $clone->message($self->message);
-    $clone->request($self->request->clone) if $self->request;
-    # we don't clone previous
-    $clone;
-}
-
 =item $r->code
 
 =item $r->code( $code )
@@ -116,29 +286,12 @@ The previous attribute is used to link together chains of responses.
 You get chains of responses if the first response is redirect or
 unauthorized.
 
-=cut
-
-sub code      { shift->_elem('_rc',      @_); }
-sub message   { shift->_elem('_msg',     @_); }
-sub previous  { shift->_elem('_previous',@_); }
-sub request   { shift->_elem('_request', @_); }
-
 =item $r->status_line
 
 Returns the string "E<lt>code> E<lt>message>".  If the message attribute
 is not set then the official name of E<lt>code> (see L<HTTP::Status>)
 is substituted.
 
-=cut
-
-sub status_line
-{
-    my $self = shift;
-    my $code = $self->{'_rc'}  || "000";
-    my $mess = $self->{'_msg'} || HTTP::Status::status_message($code) || "?";
-    return "$code $mess";
-}
-
 =item $r->base
 
 Returns the base URI for this response.  The return value will be a
@@ -175,52 +328,11 @@ initialized the "Content-Base:" header. This means that this method
 only performs the last 2 steps (the content is not always available
 either).
 
-=cut
-
-sub base
-{
-    my $self = shift;
-    my $base = $self->header('Content-Base')     ||  # used to be HTTP/1.1
-               $self->header('Content-Location') ||  # HTTP/1.1
-               $self->header('Base');                # HTTP/1.0
-    return $HTTP::URI_CLASS->new_abs($base, $self->request->uri);
-    # So yes, if $base is undef, the return value is effectively
-    # just a copy of $self->request->uri.
-}
-
-
 =item $r->as_string
 
 Returns a textual representation of the response.  Mainly
 useful for debugging purposes. It takes no arguments.
 
-=cut
-
-sub as_string
-{
-    require HTTP::Status;
-    my $self = shift;
-    my @result;
-    #push(@result, "---- $self ----");
-    my $code = $self->code;
-    my $status_message = HTTP::Status::status_message($code) || "Unknown code";
-    my $message = $self->message || "";
-
-    my $status_line = "$code";
-    my $proto = $self->protocol;
-    $status_line = "$proto $status_line" if $proto;
-    $status_line .= " ($status_message)" if $status_message ne $message;
-    $status_line .= " $message";
-    push(@result, $status_line);
-    push(@result, $self->headers_as_string);
-    my $content = $self->content;
-    if (defined $content) {
-	push(@result, $content);
-    }
-    #push(@result, ("-" x 40));
-    join("\n", @result, "");
-}
-
 =item $r->is_info
 
 =item $r->is_success
@@ -232,39 +344,12 @@ sub as_string
 These methods indicate if the response was informational, sucessful, a
 redirection, or an error.
 
-=cut
-
-sub is_info     { HTTP::Status::is_info     (shift->{'_rc'}); }
-sub is_success  { HTTP::Status::is_success  (shift->{'_rc'}); }
-sub is_redirect { HTTP::Status::is_redirect (shift->{'_rc'}); }
-sub is_error    { HTTP::Status::is_error    (shift->{'_rc'}); }
-
-
 =item $r->error_as_HTML
 
 Returns a string containing a complete HTML document indicating what
 error occurred.  This method should only be called when $r->is_error
 is TRUE.
 
-=cut
-
-sub error_as_HTML
-{
-    my $self = shift;
-    my $title = 'An Error Occurred';
-    my $body  = $self->status_line;
-    return <<EOM;
-<HTML>
-<HEAD><TITLE>$title</TITLE></HEAD>
-<BODY>
-<H1>$title</H1>
-$body
-</BODY>
-</HTML>
-EOM
-}
-
-
 =item $r->current_age
 
 Calculates the "current age" of the response as
@@ -272,42 +357,6 @@ specified by E<lt>draft-ietf-http-v11-spec-07> section 13.2.3.  The
 age of a response is the time since it was sent by the origin server.
 The returned value is a number representing the age in seconds.
 
-=cut
-
-sub current_age
-{
-    my $self = shift;
-    # Implementation of <draft-ietf-http-v11-spec-07> section 13.2.3
-    # (age calculations)
-    my $response_time = $self->client_date;
-    my $date = $self->date;
-
-    my $age = 0;
-    if ($response_time && $date) {
-	$age = $response_time - $date;  # apparent_age
-	$age = 0 if $age < 0;
-    }
-
-    my $age_v = $self->header('Age');
-    if ($age_v && $age_v > $age) {
-	$age = $age_v;   # corrected_received_age
-    }
-
-    my $request = $self->request;
-    if ($request) {
-	my $request_time = $request->date;
-	if ($request_time) {
-	    # Add response_delay to age to get 'corrected_initial_age'
-	    $age += $response_time - $request_time;
-	}
-    }
-    if ($response_time) {
-	$age += time - $response_time;
-    }
-    return $age;
-}
-
-
 =item $r->freshness_lifetime
 
 Calculates the "freshness lifetime" of the response
@@ -320,52 +369,6 @@ If the response does not contain an "Expires" or a "Cache-Control"
 header, then this function will apply some simple heuristic based on
 'Last-Modified' to determine a suitable lifetime.
 
-=cut
-
-sub freshness_lifetime
-{
-    my $self = shift;
-
-    # First look for the Cache-Control: max-age=n header
-    my @cc = $self->header('Cache-Control');
-    if (@cc) {
-	my $cc;
-	for $cc (@cc) {
-	    my $cc_dir;
-	    for $cc_dir (split(/\s*,\s*/, $cc)) {
-		if ($cc_dir =~ /max-age\s*=\s*(\d+)/i) {
-		    return $1;
-		}
-	    }
-	}
-    }
-
-    # Next possibility is to look at the "Expires" header
-    my $date = $self->date || $self->client_date || time;      
-    my $expires = $self->expires;
-    unless ($expires) {
-	# Must apply heuristic expiration
-	my $last_modified = $self->last_modified;
-	if ($last_modified) {
-	    my $h_exp = ($date - $last_modified) * 0.10;  # 10% since last-mod
-	    if ($h_exp < 60) {
-		return 60;  # minimum
-	    } elsif ($h_exp > 24 * 3600) {
-		# Should give a warning if more than 24 hours according to
-		# <draft-ietf-http-v11-spec-07> section 13.2.4, but I don't
-		# know how to do it from this function interface, so I just
-		# make this the maximum value.
-		return 24 * 3600;
-	    }
-	    return $h_exp;
-	} else {
-	    return 3600;  # 1 hour is fallback when all else fails
-	}
-    }
-    return $expires - $date;
-}
-
-
 =item $r->is_fresh
 
 Returns TRUE if the response is fresh, based on the values of
@@ -373,29 +376,10 @@ freshness_lifetime() and current_age().  If the response is no longer
 fresh, then it has to be refetched or revalidated by the origin
 server.
 
-=cut
-
-sub is_fresh
-{
-    my $self = shift;
-    $self->freshness_lifetime > $self->current_age;
-}
-
-
 =item $r->fresh_until
 
 Returns the time when this entiy is no longer fresh.
 
-=cut
-
-sub fresh_until
-{
-    my $self = shift;
-    return $self->freshness_lifetime - $self->current_age + time;
-}
-
-1;
-
 =back
 
 =head1 COPYRIGHT
@@ -405,4 +389,3 @@ Copyright 1995-2001 Gisle Aas.
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-=cut
